@@ -1,3 +1,7 @@
+from matflow_defdap import main_func
+
+
+@main_func
 def link_EBSD_DIC_maps(EbsdMap, DicMap, dic_homog_points, dic_min_grain_size,
                        ebsd_homog_points, transform_type):
 
