@@ -2,7 +2,10 @@ from pathlib import Path
 
 import defdap.ebsd as ebsd
 
+from matflow_defdap import main_func
 
+
+@main_func
 def load_EBSD_map(root_path, ebsd_filename, ebsd_structure, ebsd_flip_vert, ebsd_boundary_tol,
                   ebsd_min_grain_size):
     'Load EBSD map and detect grains.'
